@@ -44,8 +44,12 @@ class Model(Base):
     _FIELD_CONSTRAINED_VALUES = 'constrained_values'
     _FIELD_DATA_TYPE = 'data_type'
     _FIELD_ERROR = 'error'
+    _FIELD_EXECUTIONS = 'executions'
     _FIELD_FILE_TYPE = 'file_type'
+    _FIELD_GROUP_COUNT = 'group_count'
     _FIELD_GROUP_ID = 'group_id'
+    _FIELD_GROUP_INDEX = 'group_index'
+    _FIELD_HAS_EXECUTIONS = 'has_executions'
     _FIELD_ID = 'id'
     _FIELD_INPUT = 'input'
     _FIELD_INPUTS = 'inputs'
@@ -55,6 +59,7 @@ class Model(Base):
     _FIELD_OUTPUTS = 'outputs'
     _FIELD_PROCESS_STATUS = 'process_status'
     _FIELD_SSD_ID = 'ssd_id'
+    _FIELD_STARTED_AT = 'started_at'
     _FIELD_PUBLISHABLE = 'publishable'
     _FIELD_SIZE = 'size'
     _FIELD_VALIDATION = 'validation'
@@ -99,7 +104,7 @@ class Model(Base):
     _METADATA_READ_ONLY = 'read_only'
 
     # API job update frequency check.
-    _API_UPDATE_WAIT_PERIOD = 5  # Time in seconds to wait between checking jobs on the API.
+    _API_UPDATE_WAIT_PERIOD = 10  # Time in seconds to wait between checking jobs on the API.
 
     def __init__(self, session, schema=None):
         """
